# umcu-ai-utils

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

Author: AI for Health
Email: r.peters-7@umcutrecht.nl

This repository contains utilities and configuration files for the AI for Health team at UMC Utrecht. This includes but is not limited to:
- Custom visualisation settings for matplotlib
- Configuration for logging (TODO)
- Utility functions for connecting to databases (TODO)

## Installation

To install the umcu_ai_utils package use:

```{bash}
uv sync
```
